==> qtjambi-designer-debuginfo-macos-5.15.17.jar: sources/QtJambiDesigner/QDesignerIntegration_shell.h <==
#ifndef QDESIGNERINTEGRATION_SHELL_H
#define QDESIGNERINTEGRATION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDesigner/abstractintegration.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtDesigner/abstractformwindow.h>
#include <QtDesigner/abstractresourcebrowser.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerIntegration_shell : public QDesignerIntegration, public QtJambiShellInterface
{
public:
    QDesignerIntegration_shell(QDesignerFormEditorInterface* core0, QObject* parent1 = nullptr);
    ~QDesignerIntegration_shell() override;

    void addDynamicProperty(const QString& name0, const QVariant& value1) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWidget* containerWindow(QWidget* widget0) const override;
    QString contextHelpId() const override;
    QDesignerResourceBrowserInterface* createResourceBrowser(QWidget* parent0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QDesignerIntegrationInterface::Feature features() const override;
    QString headerSuffix() const override;
    bool isHeaderLowercase() const override;
    void removeDynamicProperty(const QString& name0) override;
    void resetProperty(const QString& name0) override;
    QDesignerIntegrationInterface::ResourceFileWatcherBehaviour resourceFileWatcherBehaviour() const override;
    void setFeatures(QDesignerIntegrationInterface::Feature f0) override;
    void setHeaderLowercase(bool headerLowerCase0) override;
    void setHeaderSuffix(const QString& headerSuffix0) override;
    void setResourceFileWatcherBehaviour(QDesignerIntegrationInterface::ResourceFileWatcherBehaviour behaviour0) override;
    void setupFormWindow(QDesignerFormWindowInterface* formWindow0) override;
    void timerEvent(QTimerEvent* event0) override;
    void updateActiveFormWindow(QDesignerFormWindowInterface* formWindow0) override;
    void updateCustomWidgetPlugins() override;
    void updateProperty(const QString& name0, const QVariant& value1) override;
    void updateProperty(const QString& name0, const QVariant& value1, bool enableSubPropertyHandling2) override;
    void updateSelection() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerIntegration_access : public QDesignerIntegration
{
    void __qt_addDynamicProperty_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1);
    jobject __qt_containerWindow_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0) const;
    jstring __qt_contextHelpId(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_createResourceBrowser_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0);
    jint __qt_features(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_headerSuffix(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isHeaderLowercase(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_removeDynamicProperty_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    void __qt_resetProperty_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jint __qt_resourceFileWatcherBehaviour(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setFeatures_QDesignerIntegrationInterface_Feature(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint f0);
    void __qt_setHeaderLowercase_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean headerLowerCase0);
    void __qt_setHeaderSuffix_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring headerSuffix0);
    void __qt_setResourceFileWatcherBehaviour_QDesignerIntegrationInterface_ResourceFileWatcherBehaviour(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint behaviour0);
    void __qt_setupFormWindow_QDesignerFormWindowInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID formWindow0);
    void __qt_updateActiveFormWindow_QDesignerFormWindowInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID formWindow0);
    void __qt_updateCustomWidgetPlugins(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_updateProperty_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1);
    void __qt_updateProperty_cref_QString_cref_QVariant_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1, jboolean enableSubPropertyHandling2);
    void __qt_updateSelection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QDESIGNERINTEGRATION_SHELL_H

==> qtjambi-designer-debuginfo-macos-5.15.20.jar: sources/QtJambiDesigner/QDesignerIntegration_shell.h <==
#ifndef QDESIGNERINTEGRATION_SHELL_H
#define QDESIGNERINTEGRATION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/abstractintegration.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtDesigner/abstractformwindow.h>
#include <QtDesigner/abstractresourcebrowser.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerIntegration_shell : public QDesignerIntegration, public QtJambiShellInterface
{
public:
    QDesignerIntegration_shell(QDesignerFormEditorInterface* core0, QObject* parent1 = nullptr);
    ~QDesignerIntegration_shell() override;

    void addDynamicProperty(const QString& name0, const QVariant& value1) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWidget* containerWindow(QWidget* widget0) const override;
    QString contextHelpId() const override;
    QDesignerResourceBrowserInterface* createResourceBrowser(QWidget* parent0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QDesignerIntegrationInterface::Feature features() const override;
    QString headerSuffix() const override;
    bool isHeaderLowercase() const override;
    void removeDynamicProperty(const QString& name0) override;
    void resetProperty(const QString& name0) override;
    QDesignerIntegrationInterface::ResourceFileWatcherBehaviour resourceFileWatcherBehaviour() const override;
    void setFeatures(QDesignerIntegrationInterface::Feature f0) override;
    void setHeaderLowercase(bool headerLowerCase0) override;
    void setHeaderSuffix(const QString& headerSuffix0) override;
    void setResourceFileWatcherBehaviour(QDesignerIntegrationInterface::ResourceFileWatcherBehaviour behaviour0) override;
    void setupFormWindow(QDesignerFormWindowInterface* formWindow0) override;
    void timerEvent(QTimerEvent* event0) override;
    void updateActiveFormWindow(QDesignerFormWindowInterface* formWindow0) override;
    void updateCustomWidgetPlugins() override;
    void updateProperty(const QString& name0, const QVariant& value1) override;
    void updateProperty(const QString& name0, const QVariant& value1, bool enableSubPropertyHandling2) override;
    void updateSelection() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerIntegration_access : public QDesignerIntegration
{
    void __qt_addDynamicProperty_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1);
    jobject __qt_containerWindow_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0) const;
    jstring __qt_contextHelpId_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_createResourceBrowser_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0);
    jint __qt_features_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_headerSuffix_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isHeaderLowercase_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_removeDynamicProperty_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    void __qt_resetProperty_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jint __qt_resourceFileWatcherBehaviour_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setFeatures_QDesignerIntegrationInterface_Feature(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint f0);
    void __qt_setHeaderLowercase_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean headerLowerCase0);
    void __qt_setHeaderSuffix_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring headerSuffix0);
    void __qt_setResourceFileWatcherBehaviour_QDesignerIntegrationInterface_ResourceFileWatcherBehaviour(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint behaviour0);
    void __qt_setupFormWindow_QDesignerFormWindowInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID formWindow0);
    void __qt_updateActiveFormWindow_QDesignerFormWindowInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID formWindow0);
    void __qt_updateCustomWidgetPlugins(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_updateProperty_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1);
    void __qt_updateProperty_cref_QString_cref_QVariant_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1, jboolean enableSubPropertyHandling2);
    void __qt_updateSelection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QDESIGNERINTEGRATION_SHELL_H
